# [Zope-tests] OK : Zope Buildbot / zope2.14-py2.6 slave-ubuntu64

jdriessen at thehealthagency.com jdriessen at thehealthagency.com
Thu Feb 3 14:51:26 EST 2011

- Previous message: [Zope-tests] OK : Zope Buildbot / zope2.13-py2.7 slave-ubuntu64
- Next message: [Zope-tests] OK : Zope Buildbot / zope2.14-py2.7 slave-ubuntu64
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : Zope Buildbot / zope2.14-py2.6 slave-ubuntu64
    Build: http://dev.thehealthagency.com/buildbot/builders/zope2.14-py2.6%20slave-ubuntu64/builds/145

    Build Reason: The Periodic scheduler named 'Periodic scheduler for zope2.14-py2.6' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://dev.thehealthagency.com/buildbot/

- Previous message: [Zope-tests] OK : Zope Buildbot / zope2.13-py2.7 slave-ubuntu64
- Next message: [Zope-tests] OK : Zope Buildbot / zope2.14-py2.7 slave-ubuntu64
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list